@@ -1,10 +1,10 @@
 filter.shw<-function(data, shw)
 {
   if(!is.data.frame(data))
-      stop("invalid input parameter specification: check data")
+      stop("Invalid input parameter specification: check data")
       
   if(!is.character(shw) || nchar(shw)!=3 || !grepl("^[A-Z]+$",shw) )
-      stop("invalid input parameter specification: check shw format")
+      stop("Invalid input parameter specification: check shw format")
       
   if(!("Shower"%in%names(data)))
      stop("Error: data does not contain column named Shower")
